# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ytsaurus/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ytsaurus/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/ytsaurus/v1/cluster.proto\x12\x18yandex.cloud.ytsaurus.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\xc6\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.ytsaurus.v1.Cluster.LabelsEntry\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x33\n\x04spec\x18\t \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\r \x01(\t\x12\x38\n\x06status\x18\x0e \x01(\x0e\x32(.yandex.cloud.ytsaurus.v1.Cluster.Status\x12\x38\n\x06health\x18\x0f \x01(\x0e\x32(.yandex.cloud.ytsaurus.v1.Cluster.Health\x12>\n\tendpoints\x18\x10 \x01(\x0b\x32+.yandex.cloud.ytsaurus.v1.Cluster.Endpoints\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8e\x01\n\tEndpoints\x12\n\n\x02ui\x18\x01 \x01(\t\x12$\n\x1c\x65xternal_http_proxy_balancer\x18\x02 \x01(\t\x12!\n\x19internal_http_proxy_alias\x18\x03 \x01(\t\x12 \n\x18internal_rpc_proxy_alias\x18\x04 \x01(\tJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x87\x01\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07\x12\x0c\n\x08\x44\x45LETING\x10\x08\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xf5\x01\n\x0bStorageSpec\x12:\n\x03hdd\x18\x01 \x01(\x0b\x32-.yandex.cloud.ytsaurus.v1.StorageSpec.HddSpec\x12:\n\x03ssd\x18\x02 \x01(\x0b\x32-.yandex.cloud.ytsaurus.v1.StorageSpec.SsdSpec\x1a/\n\x07HddSpec\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02\x1a=\n\x07SsdSpec\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x03J\x04\x08\x01\x10\x02\"\xfa\x03\n\x0b\x43omputeSpec\x12\x0e\n\x06preset\x18\x01 \x01(\t\x12=\n\x05\x64isks\x18\x02 \x03(\x0b\x32..yandex.cloud.ytsaurus.v1.ComputeSpec.DiskSpec\x12G\n\x0cscale_policy\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a<\n\x08\x44iskSpec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\x11\n\tlocations\x18\x03 \x03(\t\x1a\x86\x02\n\x0bScalePolicy\x12M\n\x05\x66ixed\x18\x01 \x01(\x0b\x32<.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy.FixedScaleH\x00\x12K\n\x04\x61uto\x18\x02 \x01(\x0b\x32;.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy.AutoScaleH\x00\x1a\x1a\n\nFixedScale\x12\x0c\n\x04size\x18\x01 \x01(\x03\x1a/\n\tAutoScale\x12\x10\n\x08min_size\x18\x01 \x01(\x03\x12\x10\n\x08max_size\x18\x02 \x01(\x03\x42\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"$\n\rHttpProxySpec\x12\r\n\x05\x63ount\x18\x02 \x01(\x03J\x04\x08\x01\x10\x02\"#\n\x0cRpcProxySpec\x12\r\n\x05\x63ount\x18\x02 \x01(\x03J\x04\x08\x01\x10\x02\"+\n\nTabletSpec\x12\x0e\n\x06preset\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"w\n\tProxySpec\x12\x35\n\x04http\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ytsaurus.v1.HttpProxySpec\x12\x33\n\x03rpc\x18\x02 \x01(\x0b\x32&.yandex.cloud.ytsaurus.v1.RpcProxySpec\"9\n\x08OdinSpec\x12-\n\nchecks_ttl\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x99\x02\n\x0b\x43lusterSpec\x12\x36\n\x07storage\x18\x01 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.StorageSpec\x12\x36\n\x07\x63ompute\x18\x02 \x03(\x0b\x32%.yandex.cloud.ytsaurus.v1.ComputeSpec\x12\x34\n\x06tablet\x18\x03 \x01(\x0b\x32$.yandex.cloud.ytsaurus.v1.TabletSpec\x12\x32\n\x05proxy\x18\x04 \x01(\x0b\x32#.yandex.cloud.ytsaurus.v1.ProxySpec\x12\x30\n\x04odin\x18\x05 \x01(\x0b\x32\".yandex.cloud.ytsaurus.v1.OdinSpecBe\n\x1cyandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ytsaurus.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurus'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_COMPUTESPEC_SCALEPOLICY'].oneofs_by_name['policy']._loaded_options = None
  _globals['_COMPUTESPEC_SCALEPOLICY'].oneofs_by_name['policy']._serialized_options = b'\300\3011\001'
  _globals['_CLUSTER']._serialized_start=165
  _globals['_CLUSTER']._serialized_end=1131
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=738
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=783
  _globals['_CLUSTER_ENDPOINTS']._serialized_start=786
  _globals['_CLUSTER_ENDPOINTS']._serialized_end=928
  _globals['_CLUSTER_STATUS']._serialized_start=931
  _globals['_CLUSTER_STATUS']._serialized_end=1066
  _globals['_CLUSTER_HEALTH']._serialized_start=1068
  _globals['_CLUSTER_HEALTH']._serialized_end=1131
  _globals['_STORAGESPEC']._serialized_start=1134
  _globals['_STORAGESPEC']._serialized_end=1379
  _globals['_STORAGESPEC_HDDSPEC']._serialized_start=1269
  _globals['_STORAGESPEC_HDDSPEC']._serialized_end=1316
  _globals['_STORAGESPEC_SSDSPEC']._serialized_start=1318
  _globals['_STORAGESPEC_SSDSPEC']._serialized_end=1379
  _globals['_COMPUTESPEC']._serialized_start=1382
  _globals['_COMPUTESPEC']._serialized_end=1888
  _globals['_COMPUTESPEC_DISKSPEC']._serialized_start=1563
  _globals['_COMPUTESPEC_DISKSPEC']._serialized_end=1623
  _globals['_COMPUTESPEC_SCALEPOLICY']._serialized_start=1626
  _globals['_COMPUTESPEC_SCALEPOLICY']._serialized_end=1888
  _globals['_COMPUTESPEC_SCALEPOLICY_FIXEDSCALE']._serialized_start=1797
  _globals['_COMPUTESPEC_SCALEPOLICY_FIXEDSCALE']._serialized_end=1823
  _globals['_COMPUTESPEC_SCALEPOLICY_AUTOSCALE']._serialized_start=1825
  _globals['_COMPUTESPEC_SCALEPOLICY_AUTOSCALE']._serialized_end=1872
  _globals['_HTTPPROXYSPEC']._serialized_start=1890
  _globals['_HTTPPROXYSPEC']._serialized_end=1926
  _globals['_RPCPROXYSPEC']._serialized_start=1928
  _globals['_RPCPROXYSPEC']._serialized_end=1963
  _globals['_TABLETSPEC']._serialized_start=1965
  _globals['_TABLETSPEC']._serialized_end=2008
  _globals['_PROXYSPEC']._serialized_start=2010
  _globals['_PROXYSPEC']._serialized_end=2129
  _globals['_ODINSPEC']._serialized_start=2131
  _globals['_ODINSPEC']._serialized_end=2188
  _globals['_CLUSTERSPEC']._serialized_start=2191
  _globals['_CLUSTERSPEC']._serialized_end=2472
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ai/assistants/v1/common.proto\x12\x1dyandex.cloud.ai.assistants.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xf2\x02\n\x17PromptTruncationOptions\x12\x36\n\x11max_prompt_tokens\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\\\n\rauto_strategy\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.ai.assistants.v1.PromptTruncationOptions.AutoStrategyH\x00\x12m\n\x16last_messages_strategy\x18\x03 \x01(\x0b\x32K.yandex.cloud.ai.assistants.v1.PromptTruncationOptions.LastMessagesStrategyH\x00\x1a\x0e\n\x0c\x41utoStrategy\x1a,\n\x14LastMessagesStrategy\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x03\x42\x14\n\x12TruncationStrategy\"w\n\x11\x43ompletionOptions\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0btemperature\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xdf\x01\n\x04Tool\x12\x46\n\x0csearch_index\x18\x01 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.SearchIndexToolH\x00\x12?\n\x08\x66unction\x18\x02 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.FunctionToolH\x00\x12\x42\n\ngen_search\x18\x03 \x01(\x0b\x32,.yandex.cloud.ai.assistants.v1.GenSearchToolH\x00\x42\n\n\x08ToolType\"`\n\x08ToolCall\x12\x44\n\rfunction_call\x18\x01 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.FunctionCallH\x00\x42\x0e\n\x0cToolCallType\"K\n\x0cToolCallList\x12;\n\ntool_calls\x18\x01 \x03(\x0b\x32\'.yandex.cloud.ai.assistants.v1.ToolCall\"h\n\nToolResult\x12H\n\x0f\x66unction_result\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.FunctionResultH\x00\x42\x10\n\x0eToolResultType\"Q\n\x0eToolResultList\x12?\n\x0ctool_results\x18\x01 \x03(\x0b\x32).yandex.cloud.ai.assistants.v1.ToolResult\"\xf1\x01\n\x0fSearchIndexTool\x12\x18\n\x10search_index_ids\x18\x01 \x03(\t\x12\x34\n\x0fmax_num_results\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n\x11rephraser_options\x18\x03 \x01(\x0b\x32/.yandex.cloud.ai.assistants.v1.RephraserOptions\x12\x42\n\rcall_strategy\x18\x04 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.CallStrategy\"\xf7\x01\n\x0c\x43\x61llStrategy\x12M\n\x0b\x61lways_call\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.CallStrategy.AlwaysCallH\x00\x12I\n\tauto_call\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.ai.assistants.v1.CallStrategy.AutoCallH\x00\x1a\x0c\n\nAlwaysCall\x1a\x33\n\x08\x41utoCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x0binstruction\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x42\n\n\x08Strategy\"^\n\x0c\x46unctionTool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"H\n\x0c\x46unctionCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\targuments\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x0e\x46unctionResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\r\n\x0b\x43ontentType\"/\n\x10RephraserOptions\x12\x1b\n\rrephraser_uri\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"5\n\nJsonSchema\x12\'\n\x06schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"{\n\x0eResponseFormat\x12\x15\n\x0bjson_object\x18\x01 \x01(\x08H\x00\x12@\n\x0bjson_schema\x18\x02 \x01(\x0b\x32).yandex.cloud.ai.assistants.v1.JsonSchemaH\x00\x42\x10\n\x0eResponseFormat\"l\n\rGenSearchTool\x12@\n\x07options\x18\x01 \x01(\x0b\x32/.yandex.cloud.ai.assistants.v1.GenSearchOptions\x12\x19\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xaf\x07\n\x10GenSearchOptions\x12J\n\x04site\x18\x01 \x01(\x0b\x32:.yandex.cloud.ai.assistants.v1.GenSearchOptions.SiteOptionH\x00\x12J\n\x04host\x18\x02 \x01(\x0b\x32:.yandex.cloud.ai.assistants.v1.GenSearchOptions.HostOptionH\x00\x12H\n\x03url\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.ai.assistants.v1.GenSearchOptions.UrlOptionH\x00\x12\x18\n\x10\x65nable_nrfm_docs\x18\x04 \x01(\x08\x12^\n\x0esearch_filters\x18\x05 \x03(\x0b\x32<.yandex.cloud.ai.assistants.v1.GenSearchOptions.SearchFilterB\x08\x82\xc8\x31\x04<=10\x1a/\n\nSiteOption\x12!\n\x04site\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05<=100\x8a\xc8\x31\x06<=1024\x1a-\n\tUrlOption\x12 \n\x03url\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05<=100\x8a\xc8\x31\x06<=1024\x1a/\n\nHostOption\x12!\n\x04host\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05<=100\x8a\xc8\x31\x06<=1024\x1a\x9d\x03\n\x0cSearchFilter\x12\x18\n\x04\x64\x61te\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=25H\x00\x12\x15\n\x04lang\x18\x02 \x01(\tB\x05\x8a\xc8\x31\x01\x32H\x00\x12X\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x46.yandex.cloud.ai.assistants.v1.GenSearchOptions.SearchFilter.DocFormatH\x00\"\xef\x01\n\tDocFormat\x12\x1a\n\x16\x44OC_FORMAT_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x44OC_FORMAT_PDF\x10\x01\x12\x12\n\x0e\x44OC_FORMAT_XLS\x10\x02\x12\x12\n\x0e\x44OC_FORMAT_ODS\x10\x03\x12\x12\n\x0e\x44OC_FORMAT_RTF\x10\x04\x12\x12\n\x0e\x44OC_FORMAT_PPT\x10\x05\x12\x12\n\x0e\x44OC_FORMAT_ODP\x10\x06\x12\x12\n\x0e\x44OC_FORMAT_SWF\x10\x07\x12\x12\n\x0e\x44OC_FORMAT_ODT\x10\x08\x12\x12\n\x0e\x44OC_FORMAT_ODG\x10\t\x12\x12\n\x0e\x44OC_FORMAT_DOC\x10\nB\x10\n\x0e\x66ilter_optionsB\x0e\n\x0csite_optionsBq\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistants'
  _globals['_CALLSTRATEGY_AUTOCALL'].fields_by_name['instruction']._loaded_options = None
  _globals['_CALLSTRATEGY_AUTOCALL'].fields_by_name['instruction']._serialized_options = b'\350\3071\001'
  _globals['_REPHRASEROPTIONS'].fields_by_name['rephraser_uri']._loaded_options = None
  _globals['_REPHRASEROPTIONS'].fields_by_name['rephraser_uri']._serialized_options = b'\350\3071\001'
  _globals['_GENSEARCHTOOL'].fields_by_name['description']._loaded_options = None
  _globals['_GENSEARCHTOOL'].fields_by_name['description']._serialized_options = b'\350\3071\001'
  _globals['_GENSEARCHOPTIONS_SITEOPTION'].fields_by_name['site']._loaded_options = None
  _globals['_GENSEARCHOPTIONS_SITEOPTION'].fields_by_name['site']._serialized_options = b'\202\3101\005<=100\212\3101\006<=1024'
  _globals['_GENSEARCHOPTIONS_URLOPTION'].fields_by_name['url']._loaded_options = None
  _globals['_GENSEARCHOPTIONS_URLOPTION'].fields_by_name['url']._serialized_options = b'\202\3101\005<=100\212\3101\006<=1024'
  _globals['_GENSEARCHOPTIONS_HOSTOPTION'].fields_by_name['host']._loaded_options = None
  _globals['_GENSEARCHOPTIONS_HOSTOPTION'].fields_by_name['host']._serialized_options = b'\202\3101\005<=100\212\3101\006<=1024'
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER'].fields_by_name['date']._loaded_options = None
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER'].fields_by_name['date']._serialized_options = b'\212\3101\004<=25'
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER'].fields_by_name['lang']._loaded_options = None
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER'].fields_by_name['lang']._serialized_options = b'\212\3101\0012'
  _globals['_GENSEARCHOPTIONS'].fields_by_name['search_filters']._loaded_options = None
  _globals['_GENSEARCHOPTIONS'].fields_by_name['search_filters']._serialized_options = b'\202\3101\004<=10'
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_start=171
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_end=541
  _globals['_PROMPTTRUNCATIONOPTIONS_AUTOSTRATEGY']._serialized_start=459
  _globals['_PROMPTTRUNCATIONOPTIONS_AUTOSTRATEGY']._serialized_end=473
  _globals['_PROMPTTRUNCATIONOPTIONS_LASTMESSAGESSTRATEGY']._serialized_start=475
  _globals['_PROMPTTRUNCATIONOPTIONS_LASTMESSAGESSTRATEGY']._serialized_end=519
  _globals['_COMPLETIONOPTIONS']._serialized_start=543
  _globals['_COMPLETIONOPTIONS']._serialized_end=662
  _globals['_TOOL']._serialized_start=665
  _globals['_TOOL']._serialized_end=888
  _globals['_TOOLCALL']._serialized_start=890
  _globals['_TOOLCALL']._serialized_end=986
  _globals['_TOOLCALLLIST']._serialized_start=988
  _globals['_TOOLCALLLIST']._serialized_end=1063
  _globals['_TOOLRESULT']._serialized_start=1065
  _globals['_TOOLRESULT']._serialized_end=1169
  _globals['_TOOLRESULTLIST']._serialized_start=1171
  _globals['_TOOLRESULTLIST']._serialized_end=1252
  _globals['_SEARCHINDEXTOOL']._serialized_start=1255
  _globals['_SEARCHINDEXTOOL']._serialized_end=1496
  _globals['_CALLSTRATEGY']._serialized_start=1499
  _globals['_CALLSTRATEGY']._serialized_end=1746
  _globals['_CALLSTRATEGY_ALWAYSCALL']._serialized_start=1669
  _globals['_CALLSTRATEGY_ALWAYSCALL']._serialized_end=1681
  _globals['_CALLSTRATEGY_AUTOCALL']._serialized_start=1683
  _globals['_CALLSTRATEGY_AUTOCALL']._serialized_end=1734
  _globals['_FUNCTIONTOOL']._serialized_start=1748
  _globals['_FUNCTIONTOOL']._serialized_end=1842
  _globals['_FUNCTIONCALL']._serialized_start=1844
  _globals['_FUNCTIONCALL']._serialized_end=1916
  _globals['_FUNCTIONRESULT']._serialized_start=1918
  _globals['_FUNCTIONRESULT']._serialized_end=1982
  _globals['_REPHRASEROPTIONS']._serialized_start=1984
  _globals['_REPHRASEROPTIONS']._serialized_end=2031
  _globals['_JSONSCHEMA']._serialized_start=2033
  _globals['_JSONSCHEMA']._serialized_end=2086
  _globals['_RESPONSEFORMAT']._serialized_start=2088
  _globals['_RESPONSEFORMAT']._serialized_end=2211
  _globals['_GENSEARCHTOOL']._serialized_start=2213
  _globals['_GENSEARCHTOOL']._serialized_end=2321
  _globals['_GENSEARCHOPTIONS']._serialized_start=2324
  _globals['_GENSEARCHOPTIONS']._serialized_end=3267
  _globals['_GENSEARCHOPTIONS_SITEOPTION']._serialized_start=2692
  _globals['_GENSEARCHOPTIONS_SITEOPTION']._serialized_end=2739
  _globals['_GENSEARCHOPTIONS_URLOPTION']._serialized_start=2741
  _globals['_GENSEARCHOPTIONS_URLOPTION']._serialized_end=2786
  _globals['_GENSEARCHOPTIONS_HOSTOPTION']._serialized_start=2788
  _globals['_GENSEARCHOPTIONS_HOSTOPTION']._serialized_end=2835
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER']._serialized_start=2838
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER']._serialized_end=3251
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER_DOCFORMAT']._serialized_start=2994
  _globals['_GENSEARCHOPTIONS_SEARCHFILTER_DOCFORMAT']._serialized_end=3233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/threads/message.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/threads/message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.ai.assistants.v1.searchindex import search_index_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_searchindex_dot_search__index__pb2
from yandex.cloud.ai.files.v1 import file_pb2 as yandex_dot_cloud_dot_ai_dot_files_dot_v1_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/ai/assistants/v1/threads/message.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a\x1fgoogle/protobuf/timestamp.proto\x1a<yandex/cloud/ai/assistants/v1/searchindex/search_index.proto\x1a#yandex/cloud/ai/files/v1/file.proto\"\xe5\x04\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tthread_id\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x06\x61uthor\x18\x05 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12J\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.threads.Message.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x12L\n\x06status\x18\x08 \x01(\x0e\x32<.yandex.cloud.ai.assistants.v1.threads.Message.MessageStatus\x12\x42\n\tcitations\x18\t \x03(\x0b\x32/.yandex.cloud.ai.assistants.v1.threads.Citation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\rMessageStatus\x12\x1e\n\x1aMESSAGE_STATUS_UNSPECIFIED\x10\x00\x12\r\n\tCOMPLETED\x10\x01\x12\r\n\tTRUNCATED\x10\x02\x12\x14\n\x10\x46ILTERED_CONTENT\x10\x03\"U\n\x0eMessageContent\x12\x43\n\x07\x63ontent\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.ContentPart\"\x93\x02\n\x0bMessageData\x12=\n\x06\x61uthor\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12N\n\x06labels\x18\x02 \x03(\x0b\x32>.yandex.cloud.ai.assistants.v1.threads.MessageData.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x17\n\x04Text\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"V\n\x0b\x43ontentPart\x12;\n\x04text\x18\x01 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.threads.TextH\x00\x42\n\n\x08PartType\"\"\n\x06\x41uthor\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"J\n\x08\x43itation\x12>\n\x07sources\x18\x04 \x03(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Source\"Y\n\x06Source\x12\x41\n\x05\x63hunk\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.threads.FileChunkH\x00\x42\x0c\n\nSourceType\"\xd4\x01\n\tFileChunk\x12L\n\x0csearch_index\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.searchindex.SearchIndex\x12\x33\n\x0bsource_file\x18\x02 \x01(\x0b\x32\x1e.yandex.cloud.ai.files.v1.File\x12\x44\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.ai.assistants.v1.threads.ChunkContent\"S\n\x0c\x43hunkContent\x12\x43\n\x07\x63ontent\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.ContentPartB~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _globals['_MESSAGE_LABELSENTRY']._loaded_options = None
  _globals['_MESSAGE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGEDATA_LABELSENTRY']._loaded_options = None
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGE']._serialized_start=227
  _globals['_MESSAGE']._serialized_end=840
  _globals['_MESSAGE_LABELSENTRY']._serialized_start=694
  _globals['_MESSAGE_LABELSENTRY']._serialized_end=739
  _globals['_MESSAGE_MESSAGESTATUS']._serialized_start=741
  _globals['_MESSAGE_MESSAGESTATUS']._serialized_end=840
  _globals['_MESSAGECONTENT']._serialized_start=842
  _globals['_MESSAGECONTENT']._serialized_end=927
  _globals['_MESSAGEDATA']._serialized_start=930
  _globals['_MESSAGEDATA']._serialized_end=1205
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_start=694
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_end=739
  _globals['_TEXT']._serialized_start=1207
  _globals['_TEXT']._serialized_end=1230
  _globals['_CONTENTPART']._serialized_start=1232
  _globals['_CONTENTPART']._serialized_end=1318
  _globals['_AUTHOR']._serialized_start=1320
  _globals['_AUTHOR']._serialized_end=1354
  _globals['_CITATION']._serialized_start=1356
  _globals['_CITATION']._serialized_end=1430
  _globals['_SOURCE']._serialized_start=1432
  _globals['_SOURCE']._serialized_end=1521
  _globals['_FILECHUNK']._serialized_start=1524
  _globals['_FILECHUNK']._serialized_end=1736
  _globals['_CHUNKCONTENT']._serialized_start=1738
  _globals['_CHUNKCONTENT']._serialized_end=1821
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.compute.v1.instancegroup.instance_group_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InstanceGroupView:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InstanceGroupViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InstanceGroupView.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BASIC: _InstanceGroupView.ValueType  # 0
    """Doesn't include the metadata of the instance template in the server response."""
    FULL: _InstanceGroupView.ValueType  # 1
    """Returns the metadata of the instance template in the server response."""

class InstanceGroupView(_InstanceGroupView, metaclass=_InstanceGroupViewEnumTypeWrapper): ...

BASIC: InstanceGroupView.ValueType  # 0
"""Doesn't include the metadata of the instance template in the server response."""
FULL: InstanceGroupView.ValueType  # 1
"""Returns the metadata of the instance template in the server response."""
global___InstanceGroupView = InstanceGroupView

@typing.final
class ResumeInstanceGroupProcessesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to resume processes in.

    The instance group must have a `PAUSED` status ([InstanceGroup.status]).

    To get the instance group ID, make a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___ResumeInstanceGroupProcessesRequest = ResumeInstanceGroupProcessesRequest

@typing.final
class ResumeInstanceGroupProcessMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that processes are being resumed in."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___ResumeInstanceGroupProcessMetadata = ResumeInstanceGroupProcessMetadata

@typing.final
class PauseInstanceGroupProcessesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to pause processes in.

    The instance group must have an `ACTIVE` status ([InstanceGroup.status]).

    To get the instance group ID, make a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___PauseInstanceGroupProcessesRequest = PauseInstanceGroupProcessesRequest

@typing.final
class PauseInstanceGroupProcessMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that processes are being paused in."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___PauseInstanceGroupProcessMetadata = PauseInstanceGroupProcessMetadata

@typing.final
class GetInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource to return.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    view: global___InstanceGroupView.ValueType
    """Defines which information about the Instance template should be returned in the server response."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        view: global___InstanceGroupView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id", "view", b"view"]) -> None: ...

global___GetInstanceGroupRequest = GetInstanceGroupRequest

@typing.final
class CreateInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    INSTANCE_TEMPLATE_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    DEPLOY_POLICY_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_SPEC_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_SPEC_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    APPLICATION_LOAD_BALANCER_SPEC_FIELD_NUMBER: builtins.int
    AUTO_HEALING_POLICY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an instance group in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the instance group."""
    description: builtins.str
    """Description of the instance group."""
    service_account_id: builtins.str
    """ID of the service account. The service account will be used for all API calls
    made by the Instance Groups component on behalf of the user (for example, creating instances, adding them to load balancer target group, etc.). For more information, see [Service accounts](/docs/iam/concepts/users/service-accounts).
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    deletion_protection: builtins.bool
    """Flag prohibiting deletion of the instance group.

    Allowed values:</br>- `false`: The instance group can be deleted.</br>- `true`: The instance group cannot be deleted.

    The default is `false`.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def instance_template(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceTemplate:
        """Instance template that the instance group belongs to."""

    @property
    def scale_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ScalePolicy:
        """[Scaling policy](/docs/compute/concepts/instance-groups/scale) of the instance group."""

    @property
    def deploy_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.DeployPolicy:
        """Deployment policy of the instance group."""

    @property
    def allocation_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AllocationPolicy:
        """Allocation policy of the instance group by zones and regions."""

    @property
    def load_balancer_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LoadBalancerSpec:
        """Settings for balancing load between instances via [Network Load Balancer](/docs/network-load-balancer/concepts)
        (OSI model layer 3).

        If specified, a Network Load Balancer target group containing all instances from the instance group will be created
        and attributed to the instance group.
        """

    @property
    def health_checks_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.HealthChecksSpec:
        """Health checking specification. For more information, see [Health check](/docs/network-load-balancer/concepts/health-check)."""

    @property
    def variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.Variable]: ...
    @property
    def application_load_balancer_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ApplicationLoadBalancerSpec:
        """Settings for balancing load between instances via [Application Load Balancer](/docs/application-load-balancer/concepts)
        (OSI model layer 7).

        If specified, an Application Load Balancer target group containing all instances from the instance group will be created
        and attributed to the instance group.
        """

    @property
    def auto_healing_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AutoHealingPolicy:
        """AutoHealingPolicy policy of the instance group."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        instance_template: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceTemplate | None = ...,
        scale_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ScalePolicy | None = ...,
        deploy_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.DeployPolicy | None = ...,
        allocation_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AllocationPolicy | None = ...,
        load_balancer_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LoadBalancerSpec | None = ...,
        health_checks_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.HealthChecksSpec | None = ...,
        service_account_id: builtins.str = ...,
        variables: collections.abc.Iterable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.Variable] | None = ...,
        deletion_protection: builtins.bool = ...,
        application_load_balancer_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ApplicationLoadBalancerSpec | None = ...,
        auto_healing_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AutoHealingPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "application_load_balancer_spec", b"application_load_balancer_spec", "auto_healing_policy", b"auto_healing_policy", "deploy_policy", b"deploy_policy", "health_checks_spec", b"health_checks_spec", "instance_template", b"instance_template", "load_balancer_spec", b"load_balancer_spec", "scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "application_load_balancer_spec", b"application_load_balancer_spec", "auto_healing_policy", b"auto_healing_policy", "deletion_protection", b"deletion_protection", "deploy_policy", b"deploy_policy", "description", b"description", "folder_id", b"folder_id", "health_checks_spec", b"health_checks_spec", "instance_template", b"instance_template", "labels", b"labels", "load_balancer_spec", b"load_balancer_spec", "name", b"name", "scale_policy", b"scale_policy", "service_account_id", b"service_account_id", "variables", b"variables"]) -> None: ...

global___CreateInstanceGroupRequest = CreateInstanceGroupRequest

@typing.final
class CreateInstanceGroupFromYamlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_YAML_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an instance group in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    instance_group_yaml: builtins.str
    """[InstanceGroupService.Create] request in YAML format."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        instance_group_yaml: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "instance_group_yaml", b"instance_group_yaml"]) -> None: ...

global___CreateInstanceGroupFromYamlRequest = CreateInstanceGroupFromYamlRequest

@typing.final
class CreateInstanceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that is being created."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___CreateInstanceGroupMetadata = CreateInstanceGroupMetadata

@typing.final
class UpdateInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    INSTANCE_TEMPLATE_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    DEPLOY_POLICY_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_SPEC_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_SPEC_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    APPLICATION_LOAD_BALANCER_SPEC_FIELD_NUMBER: builtins.int
    AUTO_HEALING_POLICY_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to update.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    name: builtins.str
    """Name of the instance group."""
    description: builtins.str
    """Description of the instance group."""
    service_account_id: builtins.str
    """ID of the service account. The service account will be used for all API calls
    made by the Instance Groups component on behalf of the user (for example, creating instances, adding them to load balancer target group, etc.). For more information, see [Service accounts](/docs/iam/concepts/users/service-accounts).
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the instance group"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the InstanceGroup resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        The existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def instance_template(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceTemplate:
        """Instance template that the instance group belongs to."""

    @property
    def scale_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ScalePolicy:
        """[Scaling policy](/docs/compute/concepts/instance-groups/scale) of the instance group."""

    @property
    def deploy_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.DeployPolicy:
        """Deployment policy of the instance group."""

    @property
    def allocation_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AllocationPolicy:
        """Allocation policy of the instance group by zones and regions."""

    @property
    def health_checks_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.HealthChecksSpec:
        """Health checking specification. For more information, see [Health check](/docs/network-load-balancer/concepts/health-check)."""

    @property
    def load_balancer_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LoadBalancerSpec:
        """Settings for balancing load between instances via [Network Load Balancer](/docs/network-load-balancer/concepts)
        (OSI model layer 3).
        """

    @property
    def variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.Variable]: ...
    @property
    def application_load_balancer_spec(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ApplicationLoadBalancerSpec:
        """Settings for balancing load between instances via [Application Load Balancer](/docs/application-load-balancer/concepts)
        (OSI model layer 7).
        """

    @property
    def auto_healing_policy(self) -> yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AutoHealingPolicy:
        """AutoHealingPolicy policy of the instance group."""

    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        instance_template: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceTemplate | None = ...,
        scale_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ScalePolicy | None = ...,
        deploy_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.DeployPolicy | None = ...,
        allocation_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AllocationPolicy | None = ...,
        health_checks_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.HealthChecksSpec | None = ...,
        service_account_id: builtins.str = ...,
        load_balancer_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LoadBalancerSpec | None = ...,
        variables: collections.abc.Iterable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.Variable] | None = ...,
        deletion_protection: builtins.bool = ...,
        application_load_balancer_spec: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ApplicationLoadBalancerSpec | None = ...,
        auto_healing_policy: yandex.cloud.compute.v1.instancegroup.instance_group_pb2.AutoHealingPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "application_load_balancer_spec", b"application_load_balancer_spec", "auto_healing_policy", b"auto_healing_policy", "deploy_policy", b"deploy_policy", "health_checks_spec", b"health_checks_spec", "instance_template", b"instance_template", "load_balancer_spec", b"load_balancer_spec", "scale_policy", b"scale_policy", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "application_load_balancer_spec", b"application_load_balancer_spec", "auto_healing_policy", b"auto_healing_policy", "deletion_protection", b"deletion_protection", "deploy_policy", b"deploy_policy", "description", b"description", "health_checks_spec", b"health_checks_spec", "instance_group_id", b"instance_group_id", "instance_template", b"instance_template", "labels", b"labels", "load_balancer_spec", b"load_balancer_spec", "name", b"name", "scale_policy", b"scale_policy", "service_account_id", b"service_account_id", "update_mask", b"update_mask", "variables", b"variables"]) -> None: ...

global___UpdateInstanceGroupRequest = UpdateInstanceGroupRequest

@typing.final
class UpdateInstanceGroupFromYamlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_YAML_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to update.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    instance_group_yaml: builtins.str
    """[InstanceGroupService.Update] request in YAML format."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        instance_group_yaml: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id", "instance_group_yaml", b"instance_group_yaml"]) -> None: ...

global___UpdateInstanceGroupFromYamlRequest = UpdateInstanceGroupFromYamlRequest

@typing.final
class UpdateInstanceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource that is being updated.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___UpdateInstanceGroupMetadata = UpdateInstanceGroupMetadata

@typing.final
class StartInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to start.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___StartInstanceGroupRequest = StartInstanceGroupRequest

@typing.final
class StartInstanceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource that is being started."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___StartInstanceGroupMetadata = StartInstanceGroupMetadata

@typing.final
class StopInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to stop.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___StopInstanceGroupRequest = StopInstanceGroupRequest

@typing.final
class StopInstanceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource that is being stopped."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___StopInstanceGroupMetadata = StopInstanceGroupMetadata

@typing.final
class RollingRestartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_IDS_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to restart instances in.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    @property
    def managed_instance_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of managed instances in the group to restart
        To get instance IDs, use a [InstanceGroupService.ListInstances] request.
        """

    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        managed_instance_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id", "managed_instance_ids", b"managed_instance_ids"]) -> None: ...

global___RollingRestartRequest = RollingRestartRequest

@typing.final
class RollingRestartMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource that is being rolling restarted."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___RollingRestartMetadata = RollingRestartMetadata

@typing.final
class RollingRecreateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_IDS_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to recreate instances in.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    @property
    def managed_instance_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of managed instances in the group to recreate
        To get instance IDs, use a [InstanceGroupService.ListInstances] request.
        """

    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        managed_instance_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id", "managed_instance_ids", b"managed_instance_ids"]) -> None: ...

global___RollingRecreateRequest = RollingRecreateRequest

@typing.final
class RollingRecreateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource that is being rolling recreated."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___RollingRecreateMetadata = RollingRecreateMetadata

@typing.final
class DeleteInstanceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group to delete.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___DeleteInstanceGroupRequest = DeleteInstanceGroupRequest

@typing.final
class DeleteInstanceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that is being deleted.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___DeleteInstanceGroupMetadata = DeleteInstanceGroupMetadata

@typing.final
class DeleteInstancesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that the instances are being deleted from."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___DeleteInstancesMetadata = DeleteInstancesMetadata

@typing.final
class StopInstancesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that the instances are being stopped from."""
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id"]) -> None: ...

global___StopInstancesMetadata = StopInstancesMetadata

@typing.final
class ListInstanceGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list instance groups in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListInstanceGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListInstanceGroupsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on the [InstanceGroup.name] field.
    """
    view: global___InstanceGroupView.ValueType
    """Defines which information about the Instance template should be returned in the server response."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        view: global___InstanceGroupView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...

global___ListInstanceGroupsRequest = ListInstanceGroupsRequest

@typing.final
class ListInstanceGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListInstanceGroupsRequest.page_size], use
    [next_page_token] as the value
    for the [ListInstanceGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def instance_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup]:
        """Lists instance groups for the specified folder."""

    def __init__(
        self,
        *,
        instance_groups: collections.abc.Iterable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_groups", b"instance_groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListInstanceGroupsResponse = ListInstanceGroupsResponse

@typing.final
class ListInstanceGroupInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource to list instances for.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListInstanceGroupInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListInstanceGroupInstancesResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on the [ManagedInstance.name] field.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "instance_group_id", b"instance_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListInstanceGroupInstancesRequest = ListInstanceGroupInstancesRequest

@typing.final
class ListInstanceGroupInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is more than [ListInstanceGroupInstancesRequest.page_size], use
    [next_page_token] as the value
    for the [ListInstanceGroupInstancesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ManagedInstance]:
        """Lists instances for the specified instance group."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.ManagedInstance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListInstanceGroupInstancesResponse = ListInstanceGroupInstancesResponse

@typing.final
class DeleteInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_IDS_FIELD_NUMBER: builtins.int
    CREATE_ANOTHER_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that the instances are being deleted from.
    To get the ID of the instance group, use the [InstanceGroupService.List] request.
    """
    create_another: builtins.bool
    """If set to true, the target size of instance group will not be reduced and
    a new instance will be created instead of the deleted one. By default, the target size of instance group
    will be reduced by the specified number of instance IDs.
    """
    @property
    def managed_instance_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the instances to delete. Instances will be deleted along with all dependent resources.
        Only IDs from the ManagedInstance.id field are allowed, not ManagedInstance.instance_id.
        """

    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        managed_instance_ids: collections.abc.Iterable[builtins.str] | None = ...,
        create_another: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["create_another", b"create_another", "instance_group_id", b"instance_group_id", "managed_instance_ids", b"managed_instance_ids"]) -> None: ...

global___DeleteInstancesRequest = DeleteInstancesRequest

@typing.final
class StopInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_IDS_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the instance group that the instances are being stopped from.
    To get the ID of the instance group, use the [InstanceGroupService.List] request.
    """
    @property
    def managed_instance_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the instances to stop. After stopping, the instance can be updated, started, or deleted
        according to scale and deploy policies.
        Only IDs from the ManagedInstance.id field are allowed, not ManagedInstance.instance_id.
        """

    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        managed_instance_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_group_id", b"instance_group_id", "managed_instance_ids", b"managed_instance_ids"]) -> None: ...

global___StopInstancesRequest = StopInstancesRequest

@typing.final
class ListInstanceGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource to list operations for.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is more than [page_size], the service returns a [ListInstanceGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListInstanceGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on the [InstanceGroup.name] field.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "instance_group_id", b"instance_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListInstanceGroupOperationsRequest = ListInstanceGroupOperationsRequest

@typing.final
class ListInstanceGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is more than [ListInstanceGroupOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListInstanceGroupOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """Lists operations for the specified instance group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListInstanceGroupOperationsResponse = ListInstanceGroupOperationsResponse

@typing.final
class ListInstanceGroupLogRecordsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    instance_group_id: builtins.str
    """ID of the InstanceGroup resource to list logs for.
    To get the instance group ID, use a [InstanceGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListInstanceGroupLogRecordsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListInstanceGroupLogRecordsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on the [InstanceGroup.name] field.
    """
    def __init__(
        self,
        *,
        instance_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "instance_group_id", b"instance_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListInstanceGroupLogRecordsRequest = ListInstanceGroupLogRecordsRequest

@typing.final
class ListInstanceGroupLogRecordsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListInstanceGroupLogRecordsRequest.page_size], use
    [next_page_token] as the value
    for the [ListInstanceGroupLogRecordsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def log_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LogRecord]:
        """Lists logs for the specified instance group."""

    def __init__(
        self,
        *,
        log_records: collections.abc.Iterable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.LogRecord] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_records", b"log_records", "next_page_token", b"next_page_token"]) -> None: ...

global___ListInstanceGroupLogRecordsResponse = ListInstanceGroupLogRecordsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.stt.v3.stt_pb2
import yandex.cloud.ai.stt.v3.stt_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RecognizerStub:
    """A set of methods for streaming speech recognition."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    RecognizeStreaming: grpc.StreamStreamMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingRequest,
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse,
    ]
    """Performs bidirectional streaming speech recognition receiving results while sending audio."""

class RecognizerAsyncStub:
    """A set of methods for streaming speech recognition."""

    RecognizeStreaming: grpc.aio.StreamStreamMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingRequest,
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse,
    ]
    """Performs bidirectional streaming speech recognition receiving results while sending audio."""

class RecognizerServicer(metaclass=abc.ABCMeta):
    """A set of methods for streaming speech recognition."""

    @abc.abstractmethod
    def RecognizeStreaming(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.ai.stt.v3.stt_pb2.StreamingRequest],
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse], collections.abc.AsyncIterator[yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse]]:
        """Performs bidirectional streaming speech recognition receiving results while sending audio."""

def add_RecognizerServicer_to_server(servicer: RecognizerServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class AsyncRecognizerStub:
    """A set of methods for asynchronous speech recognition: recognize pre-recorded audio and receive results by request."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    RecognizeFile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.RecognizeFileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs asynchronous speech recognition."""

    GetRecognition: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.stt.v3.stt_service_pb2.GetRecognitionRequest,
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse,
    ]
    """Gets results of asynchronous recognition after finishing the operation."""

    DeleteRecognition: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.DeleteRecognitionRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Deletes results of asynchronous recognition by operation ID."""

class AsyncRecognizerAsyncStub:
    """A set of methods for asynchronous speech recognition: recognize pre-recorded audio and receive results by request."""

    RecognizeFile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.RecognizeFileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs asynchronous speech recognition."""

    GetRecognition: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.stt.v3.stt_service_pb2.GetRecognitionRequest,
        yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse,
    ]
    """Gets results of asynchronous recognition after finishing the operation."""

    DeleteRecognition: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v3.stt_pb2.DeleteRecognitionRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Deletes results of asynchronous recognition by operation ID."""

class AsyncRecognizerServicer(metaclass=abc.ABCMeta):
    """A set of methods for asynchronous speech recognition: recognize pre-recorded audio and receive results by request."""

    @abc.abstractmethod
    def RecognizeFile(
        self,
        request: yandex.cloud.ai.stt.v3.stt_pb2.RecognizeFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Performs asynchronous speech recognition."""

    @abc.abstractmethod
    def GetRecognition(
        self,
        request: yandex.cloud.ai.stt.v3.stt_service_pb2.GetRecognitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse], collections.abc.AsyncIterator[yandex.cloud.ai.stt.v3.stt_pb2.StreamingResponse]]:
        """Gets results of asynchronous recognition after finishing the operation."""

    @abc.abstractmethod
    def DeleteRecognition(
        self,
        request: yandex.cloud.ai.stt.v3.stt_pb2.DeleteRecognitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Deletes results of asynchronous recognition by operation ID."""

def add_AsyncRecognizerServicer_to_server(servicer: AsyncRecognizerServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.marketplace.licensemanager.v1.external_instance_pb2
import yandex.cloud.marketplace.licensemanager.v1.lock_pb2
import yandex.cloud.marketplace.licensemanager.v1.template_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Instance._State.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATE_UNSPECIFIED: Instance._State.ValueType  # 0
        PENDING: Instance._State.ValueType  # 1
        """Subscription created but not active yet."""
        ACTIVE: Instance._State.ValueType  # 2
        """Subscription is active."""
        CANCELLED: Instance._State.ValueType  # 3
        """Subscription canceled. It is still active, but won't be automatically renewed after the end of the current period."""
        EXPIRED: Instance._State.ValueType  # 4
        """Subscription expired."""
        DEPRECATED: Instance._State.ValueType  # 5
        """Subscription deprecated."""
        DELETED: Instance._State.ValueType  # 6
        """Subscription deleted."""

    class State(_State, metaclass=_StateEnumTypeWrapper): ...
    STATE_UNSPECIFIED: Instance.State.ValueType  # 0
    PENDING: Instance.State.ValueType  # 1
    """Subscription created but not active yet."""
    ACTIVE: Instance.State.ValueType  # 2
    """Subscription is active."""
    CANCELLED: Instance.State.ValueType  # 3
    """Subscription canceled. It is still active, but won't be automatically renewed after the end of the current period."""
    EXPIRED: Instance.State.ValueType  # 4
    """Subscription expired."""
    DEPRECATED: Instance.State.ValueType  # 5
    """Subscription deprecated."""
    DELETED: Instance.State.ValueType  # 6
    """Subscription deleted."""

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    TEMPLATE_ID_FIELD_NUMBER: builtins.int
    TEMPLATE_VERSION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    LOCKS_FIELD_NUMBER: builtins.int
    LICENSE_TEMPLATE_FIELD_NUMBER: builtins.int
    EXTERNAL_INSTANCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subscription instance."""
    cloud_id: builtins.str
    """ID of the cloud that the subscription instance belongs to."""
    folder_id: builtins.str
    """ID of the folder that the subscription instance belongs to."""
    template_id: builtins.str
    """ID of the subscription template that was used to create subscription instance."""
    template_version_id: builtins.str
    """ID of the version of subscription template."""
    description: builtins.str
    """Description of the subscription instance."""
    state: global___Instance.State.ValueType
    """Subscription state."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the start of the subscription."""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the end of the subscription."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update timestamp."""

    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock]:
        """List of subscription locks."""

    @property
    def license_template(self) -> yandex.cloud.marketplace.licensemanager.v1.template_pb2.Template:
        """Subscription template."""

    @property
    def external_instance(self) -> yandex.cloud.marketplace.licensemanager.v1.external_instance_pb2.ExternalInstance:
        """External subscription instance (optional)."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        template_id: builtins.str = ...,
        template_version_id: builtins.str = ...,
        description: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state: global___Instance.State.ValueType = ...,
        locks: collections.abc.Iterable[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock] | None = ...,
        license_template: yandex.cloud.marketplace.licensemanager.v1.template_pb2.Template | None = ...,
        external_instance: yandex.cloud.marketplace.licensemanager.v1.external_instance_pb2.ExternalInstance | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "end_time", b"end_time", "external_instance", b"external_instance", "license_template", b"license_template", "start_time", b"start_time", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "end_time", b"end_time", "external_instance", b"external_instance", "folder_id", b"folder_id", "id", b"id", "license_template", b"license_template", "locks", b"locks", "start_time", b"start_time", "state", b"state", "template_id", b"template_id", "template_version_id", b"template_version_id", "updated_at", b"updated_at"]) -> None: ...

global___Instance = Instance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2
import yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class WafProfileServiceStub:
    """A set of methods for managing WafProfile resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile,
    ]
    """Returns the specified WafProfile resource."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse,
    ]
    """Retrieves the list of WafProfile resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a WAF profile in the specified folder using the data specified in the request."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified WAF profile."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified WAF profile."""

class WafProfileServiceAsyncStub:
    """A set of methods for managing WafProfile resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile,
    ]
    """Returns the specified WafProfile resource."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse,
    ]
    """Retrieves the list of WafProfile resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a WAF profile in the specified folder using the data specified in the request."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified WAF profile."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified WAF profile."""

class WafProfileServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing WafProfile resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile, collections.abc.Awaitable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile]]:
        """Returns the specified WafProfile resource."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse, collections.abc.Awaitable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse]]:
        """Retrieves the list of WafProfile resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a WAF profile in the specified folder using the data specified in the request."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified WAF profile."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified WAF profile."""

def add_WafProfileServiceServicer_to_server(servicer: WafProfileServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/link_item.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/link_item.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import link_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_link__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/monitoring/v3/link_item.proto\x12\x1ayandex.cloud.monitoring.v3\x1a%yandex/cloud/monitoring/v3/link.proto\"\xd6\x01\n\x08LinkItem\x12\x30\n\x04link\x18\x01 \x01(\x0b\x32 .yandex.cloud.monitoring.v3.LinkH\x00\x12?\n\x05group\x18\x02 \x01(\x0b\x32..yandex.cloud.monitoring.v3.LinkItem.LinkGroupH\x00\x1aO\n\tLinkGroup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.yandex.cloud.monitoring.v3.LinkItemB\x06\n\x04typeBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.link_item_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_LINKITEM']._serialized_start=114
  _globals['_LINKITEM']._serialized_end=328
  _globals['_LINKITEM_LINKGROUP']._serialized_start=241
  _globals['_LINKITEM_LINKGROUP']._serialized_end=320
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/batch_inference/v1/inference_options.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/batch_inference/v1/inference_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/ai/batch_inference/v1/inference_options.proto\x12\"yandex.cloud.ai.batch_inference.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dyandex/cloud/validation.proto\"\xb5\x02\n\x16\x42\x61tchCompletionRequest\x12\x17\n\tmodel_uri\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11source_dataset_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12Q\n\x12\x63ompletion_options\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.batch_inference.v1.CompletionOptions\x12\x1c\n\x14\x64\x61ta_logging_enabled\x18\x04 \x01(\x08\x12\x15\n\x0bjson_object\x18\x05 \x01(\x08H\x00\x12\x45\n\x0bjson_schema\x18\x06 \x01(\x0b\x32..yandex.cloud.ai.batch_inference.v1.JsonSchemaH\x00\x42\x12\n\x10StructuredOutput\"\xc8\x01\n\x11\x43ompletionOptions\x12\x31\n\x0btemperature\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12O\n\x11reasoning_options\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.ai.batch_inference.v1.ReasoningOptions\"\xb7\x01\n\x10ReasoningOptions\x12P\n\x04mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.ai.batch_inference.v1.ReasoningOptions.ReasoningMode\"Q\n\rReasoningMode\x12\x1e\n\x1aREASONING_MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x12\n\x0e\x45NABLED_HIDDEN\x10\x02\"5\n\nJsonSchema\x12\'\n\x06schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructBu\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.batch_inference.v1.inference_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomo'
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['model_uri']._loaded_options = None
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['model_uri']._serialized_options = b'\350\3071\001'
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['source_dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_start=192
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_end=501
  _globals['_COMPLETIONOPTIONS']._serialized_start=504
  _globals['_COMPLETIONOPTIONS']._serialized_end=704
  _globals['_REASONINGOPTIONS']._serialized_start=707
  _globals['_REASONINGOPTIONS']._serialized_end=890
  _globals['_REASONINGOPTIONS_REASONINGMODE']._serialized_start=809
  _globals['_REASONINGOPTIONS_REASONINGMODE']._serialized_end=890
  _globals['_JSONSCHEMA']._serialized_start=892
  _globals['_JSONSCHEMA']._serialized_end=945
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.host_group_pb2
import yandex.cloud.compute.v1.host_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HostGroupServiceStub:
    """A set of methods for managing groups of dedicated hosts."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        yandex.cloud.compute.v1.host_group_pb2.HostGroup,
    ]
    """Returns the specified host group."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse,
    ]
    """Retrieves the list of host groups in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a host group in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified host group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified host group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse,
    ]
    """Lists operations for the specified host group."""

    ListInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse,
    ]
    """Lists instances that belongs to the specified host group."""

    ListHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse,
    ]
    """Lists hosts that belongs to the specified host group."""

    UpdateHost: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update host"""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the host group.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the host group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the host group."""

class HostGroupServiceAsyncStub:
    """A set of methods for managing groups of dedicated hosts."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        yandex.cloud.compute.v1.host_group_pb2.HostGroup,
    ]
    """Returns the specified host group."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse,
    ]
    """Retrieves the list of host groups in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a host group in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified host group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified host group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse,
    ]
    """Lists operations for the specified host group."""

    ListInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse,
    ]
    """Lists instances that belongs to the specified host group."""

    ListHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse,
    ]
    """Lists hosts that belongs to the specified host group."""

    UpdateHost: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update host"""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the host group.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the host group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the host group."""

class HostGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing groups of dedicated hosts."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_pb2.HostGroup, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_pb2.HostGroup]]:
        """Returns the specified host group."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse]]:
        """Retrieves the list of host groups in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a host group in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified host group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified host group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse]]:
        """Lists operations for the specified host group."""

    @abc.abstractmethod
    def ListInstances(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse]]:
        """Lists instances that belongs to the specified host group."""

    @abc.abstractmethod
    def ListHosts(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse]]:
        """Lists hosts that belongs to the specified host group."""

    @abc.abstractmethod
    def UpdateHost(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update host"""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the host group.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the host group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the host group."""

def add_HostGroupServiceServicer_to_server(servicer: HostGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.spark.v1.cluster_pb2
import yandex.cloud.spark.v1.maintenance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Spark clusters in."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListClusters requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListClusters
    request to get the next page of results.
    """
    filter: builtins.str
    """String that describes a display filter."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListClusters requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListClusters request. Subsequent ListClusters
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.spark.v1.cluster_pb2.Cluster]:
        """Requested list of Spark clusters."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.spark.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create Spark cluster in."""
    name: builtins.str
    """Name of the Spark cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Spark cluster. 0-256 characters long."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    service_account_id: builtins.str
    """Service account that will be used to access YC resources"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config(self) -> yandex.cloud.spark.v1.cluster_pb2.ClusterConfig: ...
    @property
    def network(self) -> yandex.cloud.spark.v1.cluster_pb2.NetworkConfig: ...
    @property
    def logging(self) -> yandex.cloud.spark.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration"""

    @property
    def maintenance_window(self) -> yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config: yandex.cloud.spark.v1.cluster_pb2.ClusterConfig | None = ...,
        network: yandex.cloud.spark.v1.cluster_pb2.NetworkConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.spark.v1.cluster_pb2.LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network", b"network", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the creating Spark cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_SPEC_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    name: builtins.str
    description: builtins.str
    """Description of the Spark cluster. 0-256 characters long."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config_spec(self) -> yandex.cloud.spark.v1.cluster_pb2.UpdateClusterConfigSpec: ...
    @property
    def network_spec(self) -> yandex.cloud.spark.v1.cluster_pb2.UpdateNetworkConfigSpec: ...
    @property
    def logging(self) -> yandex.cloud.spark.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration"""

    @property
    def maintenance_window(self) -> yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: yandex.cloud.spark.v1.cluster_pb2.UpdateClusterConfigSpec | None = ...,
        network_spec: yandex.cloud.spark.v1.cluster_pb2.UpdateNetworkConfigSpec | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.spark.v1.cluster_pb2.LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "logging", b"logging", "maintenance_window", b"maintenance_window", "network_spec", b"network_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network_spec", b"network_spec", "service_account_id", b"service_account_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the updating Spark cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the deleting Spark cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListOperations requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListOperations
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListOperations requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListOperations request. Subsequent ListOperations
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]: ...
    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse
